Telegram Bot API methods.
Modules
- _base
- answer_
callback_ query - answer_
inline_ query - delete_
message - edit_
message_ caption - edit_
message_ live_ location - edit_
message_ reply_ markup - edit_
message_ text - export_
chat_ invite_ link - forward_
message - get_
chat - get_
chat_ administrators - get_
chat_ member - get_
chat_ members_ count - get_
file - get_me
- get_
updates - get_
user_ profile_ photos - kick_
chat_ member - leave_
chat - pin_
chat_ message - send_
audio - send_
chat_ action - send_
contact - send_
document - send_
location - send_
message - send_
photo - send_
poll - send_
venue - send_
video - stop_
message_ live_ location - stop_
poll - unban_
chat_ member - unpin_
chat_ message
Structs
- Answer
Callback Query - Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to the user as a notification at the top of the chat screen or as an alert.
- Answer
Inline Query - Delete
Message - Detached
Request - Detached
Request Type - Edit
Message Caption - Use this method to edit captions of messages sent by the bot.
- Edit
Message Live Location - Use this method to edit live location messages sent by the bot. A location can be edited until its live_period expires or editing is explicitly disabled by a call to stopMessageLiveLocation.
- Edit
Message Reply Markup - Use this method to edit only the reply markup of messages sent by the bot.
- Edit
Message Text - Use this method to edit text messages sent by the bot.
- Error
- Export
Chat Invite Link - Use this method to export chat invite links.
- Forward
Message - Use this method to forward messages of any kind.
- GetChat
- Use this method to get up to date information about the chat.
- GetChat
Administrators - Use this method to get a list of administrators in a chat. If the chat is a group or a supergroup and no administrators were appointed, only the creator will be returned.
- GetChat
Member - Use this method to get information about a member of a chat.
- GetChat
Members Count - Use this method to get the number of members in a chat.
- GetFile
- Use this method to get basic info about a file and prepare it for downloading. For the moment, bots can download files of up to 20MB in size.
- GetMe
- A simple method for testing your bot’s auth token. Requires no parameters. Returns basic information about the bot in form of a User object.
- GetUpdates
- Use this method to receive incoming updates using long polling.
- GetUser
Profile Photos - Use this method to get a list of profile pictures for a user.
- Http
Request - Http
Response - Json
IdResponse - Json
Request Type - Json
True ToUnit Response - Kick
Chat Member - Use this method to kick a user from a group or a supergroup. In the case of supergroups, the user will not be able to return to the group on their own using invite links, etc., unless unbanned first. The bot must be an administrator in the group for this to work.
- Leave
Chat - Use this method for your bot to leave a group, supergroup or channel.
- Multipart
Request Type - PinChat
Message - Use this method to pin a message in a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the ‘can_pin_messages’ admin right in the supergroup or ‘can_edit_messages’ admin right in the channel.
- Send
Audio - Use this method to send an audio
- Send
Chat Action - Use this method when you need to tell the user that something is happening on the bot’s side. The status is set for 5 seconds or less (when a message arrives from your bot, Telegram clients clear its typing status).
- Send
Contact - Use this method to send phone contacts.
- Send
Document - Use this method to send general files. On success, the sent Message is returned. Bots can currently send files of any type of up to 50 MB in size, this limit may be changed in the future.
- Send
Location - Use this method to send point on the map.
- Send
Message - Use this method to send text messages.
- Send
Photo - Use this method to send photos
- Send
Poll - Use this method to send polls.
- Send
Venue - Use this method to send information about a venue.
- Send
Video - Use this method to send an video
- Stop
Message Live Location - Use this method to stop updating a live location message sent by the bot before live_period expires.
- Stop
Poll - Use this method to stop a poll which was sent by the bot.
- Unban
Chat Member - Use this method to unban a previously kicked user in a supergroup or channel. The user will not return to the group or channel automatically, but will be able to join via link, etc. The bot must be an administrator in the group for this to work.
- Unpin
Chat Message - Use this method to unpin a message in a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the ‘can_pin_messages’ admin right in the supergroup or ‘can_edit_messages’ admin right in the channel.
Enums
- Allowed
Update - Body
- Chat
Action - Strongly typed ChatAction. Instead of passing a String to the
chat_actionmethod, this is used. - Method
- Multipart
Value - Request
Url
Traits
- CanAnswer
Callback Query - Send answers to callback queries sent from inline keyboards.
- CanAnswer
Inline Query - CanDelete
Message - Delete messages..
- CanEdit
Message Caption - Edit captions of messages sent by the bot.
- CanEdit
Message Live Location - Edit live location messages sent by the bot.
- CanEdit
Message Reply Markup - Edit reply markup of messages sent by the bot.
- CanEdit
Message Text - Edit text of messages sent by the bot.
- CanExport
Chat Invite Link - Export chat invite link.
- CanForward
Message - Forward message.
- CanGet
Chat - Get up to date information about the chat.
- CanGet
Chat Administrators - Get a list of administrators in a chat.
- CanGet
Chat Member ForChat - Get information about a member of a chat.
- CanGet
Chat Member ForUser - Get information about a member of a chat.
- CanGet
Chat Members Count - Get the number of members in a chat.
- CanGet
File - Get basic info about a file and prepare it for downloading.
- CanGet
User Profile Photos - Get a list of profile pictures for a user.
- CanKick
Chat Member ForChat - Kick a user from a group or a supergroup.
- CanKick
Chat Member ForUser - Kick a user from a group or a supergroup.
- CanLeave
Chat - Leave a group, supergroup or channel.
- CanPin
Message - CanReply
Send Audio - Can reply with an audio
- CanReply
Send Contact - Reply with phone contact.
- CanReply
Send Document - Can reply with a document
- CanReply
Send Location - Reply with point on the map.
- CanReply
Send Message - Reply with text message.
- CanReply
Send Photo - Can reply with an photo
- CanReply
Send Poll - CanReply
Send Venue - Reply with information about a venue.
- CanReply
Send Video - Can reply with an video
- CanSend
Audio - Send an audio
- CanSend
Chat Action - Send
actionto a chat. - CanSend
Contact - Send phone contact.
- CanSend
Document - Send a document
- CanSend
Location - Send point on the map.
- CanSend
Message - Send text message.
- CanSend
Photo - Send an photo
- CanSend
Poll - Send message with a poll.
- CanSend
Venue - Send information about a venue.
- CanSend
Video - Send an video
- CanStop
Message Live Location - Stop updating a live location message sent by the bot.
- CanStop
Poll - Stop a poll which was sent by the bot.
- CanUnban
Chat Member ForChat - Unban a previously kicked user in a supergroup or channel.
- CanUnban
Chat Member ForUser - Unban a previously kicked user in a supergroup or channel.
- CanUnpin
Message - Json
Response - Request
- Request
Type - Response
Type - ToMultipart
- ToMultipart
Value - ToReply
Request - Use this trait to convert a complex type to corresponding request and reply to the message.
- ToRequest
- Use this trait to convert a complex type to corresponding request and send it to the chat.