pub struct UnbanChatMember { /* private fields */ }Expand description
Use this method to unban a previously kicked user in a supergroup or channel. The user will not return to the group or channel automatically, but will be able to join via link, etc. The bot must be an administrator in the group for this to work.
Implementations
Sourceimpl UnbanChatMember
impl UnbanChatMember
pub fn new<C, U>(chat: C, user: U) -> UnbanChatMember