pub trait ToRequest<'b> {
type Request: Request;
// Required method
fn to_request<C>(&'b self, chat: C) -> Self::Request
where C: ToChatRef;
}Expand description
Use this trait to convert a complex type to corresponding request and send it to the chat.
Required Associated Types
Required Methods
Sourcefn to_request<C>(&'b self, chat: C) -> Self::Requestwhere
C: ToChatRef,
fn to_request<C>(&'b self, chat: C) -> Self::Requestwhere
C: ToChatRef,
Convert type to request and send it to the chat.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".