Upon receiving a message with this object, Telegram clients will
display a reply interface to the user (act as if the user has
selected the bot‘s message and tapped ’Reply’). This can be
extremely useful if you want to create user-friendly step-by-step
interfaces without having to sacrifice privacy mod
Upon receiving a message with this object, Telegram clients will remove
the current custom keyboard and display the default letter-keyboard.
By default, custom keyboards are displayed until a new keyboard is sent
by a bot. An exception is made for one-time keyboards that are hidden
immediately after the user presses a button (see ReplyKeyboardMarkup).